@@ -39,7 +39,7 @@ class Move:
     def __setup__(cls):
         super(Move, cls).__setup__()
         cls._error_messages.update({
-                'lot_required': 'Lot is required for move of product "%s"!',
+                'lot_required': 'Lot is required for move of product "%s".',
                 })
 
     @classmethod
@@ -54,10 +54,10 @@ class Move:
                 cls.raise_user_error('lot_required', (move.product.rec_name,))
 
     @classmethod
-    def create(cls, values):
-        move = super(Move, cls).create(values)
-        cls.check_lot([move])
-        return move
+    def create(cls, vlist):
+        moves = super(Move, cls).create(vlist)
+        cls.check_lot(moves)
+        return moves
 
     @classmethod
     def write(cls, moves, values):
@@ -70,10 +70,10 @@ class ShipmentIn:
 
     @classmethod
     def _get_inventory_moves(cls, incoming_move):
-        result = super(ShipmentIn, cls)._get_inventory_moves(incoming_move)
-        if result and incoming_move.lot:
-            result['lot'] = incoming_move.lot.id
-        return result
+        move = super(ShipmentIn, cls)._get_inventory_moves(incoming_move)
+        if move and incoming_move.lot:
+            move.lot = incoming_move.lot
+        return move
 
 
 class ShipmentOut:
@@ -90,10 +90,7 @@ class ShipmentOut:
         super(ShipmentOut, cls).pack(shipments)
 
         # Unassign move to allow update
-        Move.write([m for s in shipments for m in s.outgoing_moves
-                if m.state not in ('done', 'cancel')], {
-                'state': 'draft',
-                })
+        Move.draft([m for s in shipments for m in s.outgoing_moves])
 
         for shipment in shipments:
             outgoing_by_product = {}
@@ -124,10 +121,7 @@ class ShipmentOut:
                     quantity -= out_quantity
                 assert quantity <= 0
 
-        Move.write([m for s in shipments for m in s.outgoing_moves
-                if m.state != 'cancel'], {
-                'state': 'assigned',
-                })
+        Move.assign([m for s in shipments for m in s.outgoing_moves])
 
 
 class ShipmentOutReturn:
@@ -135,8 +129,8 @@ class ShipmentOutReturn:
 
     @classmethod
     def _get_inventory_moves(cls, incoming_move):
-        result = super(ShipmentOutReturn,
+        move = super(ShipmentOutReturn,
             cls)._get_inventory_moves(incoming_move)
-        if result and incoming_move.lot:
-            result['lot'] = incoming_move.lot.id
-        return result
+        if move and incoming_move.lot:
+            move.lot = incoming_move.lot
+        return move
